#

##

##

###

###

    	bun
    		apt install unzip; curl -fsSL https://bun.sh/install | bash; source /root/.bashrc

    	install
    		(cd /habitat/venues/stages/goodest/adventures/vv_turbo/ && bun install)

    		(cd /habitat/venues/frontend/vv_turbo/apps/web && bun add @pontem/aptos-wallet-adapter)
    		(cd /habitat/venues/frontend/vv_turbo/apps/web && bun add -d @pontem/aptos-wallet-adapter)

    		(cd /habitat/venues/frontend/vv_turbo/apps/web && bun run licensing_csv)

    	on build (for business)
    		(cd /habitat/venues/stages/goodest/adventures/vv_turbo/apps/web && bun run build --watch)

    	on dev
    		(cd /habitat/venues/stages/goodest/adventures/vv_turbo/ && bun run dev)
    		localStorage.setItem ("node address", "https://192.168.0.100/")

    		#
    		# 	objective:
    		#		[ ] CORS if "nurture mode"
    		#

    	previously
    		(cd /habitat/venues/stages/goodest/adventures && npx create-turbo@latest -e with-vite)
    		(cd /habitat/venues/stages/goodest/adventures/vv_turbo/ && bun add @vitejs/plugin-vue)
    		(cd /habitat/venues/stages/goodest/adventures/vv_turbo/apps/web && bun pm untrusted)